@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ class MplayerWindow;
 class QSettings;
 
 #ifdef SCREENSAVER_OFF
-class WinScreenSaver;
+class ScreenSaver;
 #endif
 
 #ifdef YOUTUBE_SUPPORT
@@ -383,7 +383,7 @@ public slots:
 
 	//! Wrapper for the osd_show_text slave command
 	void displayTextOnOSD(QString text, int duration = 3000, int level = 1, 
-                          QString prefix = QString::null);
+                          QString prefix = QString());
 
 public:
 	//! Returns the number of the first chapter in 
@@ -394,14 +394,17 @@ public:
 
 	void changeFileSettingsMethod(QString method);
 
+	void setDisplayScreen(int n) { display_screen = n; }
+	int displayScreen() { return display_screen; }
+
 protected:
 	//! Returns the prefix to keep pausing on slave commands
 	QString pausing_prefix();
 	void seek_cmd(double secs, int mode);
 
 protected slots:
-    void changeCurrentSec(double sec);
-    void changePause();
+	void changeCurrentSec(double sec);
+	void changePause();
 	void gotWindowResolution( int w, int h );
 	void gotNoVideo();
 	void gotVO(QString);
@@ -409,6 +412,7 @@ protected slots:
 	void gotStartingTime(double);
 	void gotVideoBitrate(int);
 	void gotAudioBitrate(int);
+	void gotDemuxRotation(int);
 
 	void finishRestart();
     void processFinished();
@@ -546,6 +550,9 @@ signals:
 #ifdef YOUTUBE_SUPPORT
 	void YTprocessFailedToStart();
 	void YTUrlNotFound();
+	#ifdef Q_OS_WIN
+	void YTDLLNotFound();
+	#endif
 #endif
 
 	void receivedForbidden();
@@ -560,13 +567,15 @@ protected:
 #endif
 
 #ifdef SCREENSAVER_OFF
-	WinScreenSaver * win_screensaver;
+	ScreenSaver * screensaver;
 #endif
 
 #ifdef YOUTUBE_SUPPORT
 	RetrieveYoutubeUrl * yt;
 #endif
 
+	int display_screen;
+
 private:
 	// Some variables to proper restart
 	bool we_are_restarting;
