@@ -123,7 +123,7 @@ void MPVProcess::setMedia(const QString & media, bool is_playlist) {
 }
 
 void MPVProcess::setFixedOptions() {
-	arg << "--no-config";
+	//arg << "--no-config";
 	arg << "--no-quiet";
 	arg << "--terminal";
 	arg << "--no-msg-color";
@@ -484,7 +484,7 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 			if (l.count() == 3) {
 				#ifndef Q_OS_WIN
 				if (l[0] == "pulse") {
-					arg << "--audio-device=pulse/" + l[2];
+					arg << "--audio-device=pulse/" + l[1];
 				}
 				#if USE_MPV_ALSA_DEVICES
 				else
@@ -492,6 +492,12 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 					arg << "--audio-device=alsa/" + l[1];
 				}
 				#endif
+				#if USE_MPV_COREAUDIO_DEVICES
+				else
+				if (l[0] == "coreaudio") {
+					arg << "--audio-device=coreaudio/" + l[1];
+				}
+				#endif
 				#else
 				if (l[0] == "dsound") {
 					arg << "--audio-device=dsound/" + l[1];
@@ -595,6 +601,7 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 	    option_name == "embeddedfonts" ||
 	    option_name == "osd-scale" ||
 	    option_name == "speed" ||
+	    option_name == "screen" ||
 	    option_name == "contrast" || option_name == "brightness" ||
 	    option_name == "hue" || option_name == "saturation" || option_name == "gamma" ||
 	    option_name == "monitorpixelaspect" || option_name == "monitoraspect" ||
