@@ -28,7 +28,7 @@
 #include "helper.h"
 #include <QDebug>
 
-#if USE_ALSA_DEVICES || USE_PULSEAUDIO_DEVICES || USE_XV_ADAPTORS || USE_DSOUND_DEVICES
+#if USE_ALSA_DEVICES || USE_PULSEAUDIO_DEVICES || USE_XV_ADAPTORS || USE_DSOUND_DEVICES || USE_MPV_PULSE_DEVICES
 #include "deviceinfo.h"
 #endif
 
@@ -60,19 +60,16 @@ PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 	vo_list = i->voList();
 	ao_list = i->aoList();
 
-#if USE_DSOUND_DEVICES
+#ifdef AUDIO_DEVICES_SELECTION
+	#if USE_DSOUND_DEVICES
 	dsound_devices = DeviceInfo::dsoundDevices();
+	#endif
+
+	#if USE_ALSA_DEVICES
+	alsa_devices = DeviceInfo::alsaDevices();
+	#endif
 #endif
 
-#if USE_ALSA_DEVICES
-	alsa_devices = DeviceInfo::alsaDevices();
-#endif
-#if USE_MPV_ALSA_DEVICES
-	mpv_alsa_devices = DeviceInfo::mpvAlsaDevices();
-#endif
-#if USE_PULSEAUDIO_DEVICES
-	pa_devices = DeviceInfo::paDevices();
-#endif
 #if USE_XV_ADAPTORS
 	xv_adaptors = DeviceInfo::xvAdaptors();
 #endif
@@ -195,7 +192,9 @@ void PrefGeneral::retranslateStrings() {
 	filesettings_method_combo->addItem( tr("multiple ini files"), "hash");
 	filesettings_method_combo->setCurrentIndex(filesettings_method_item);
 
+#ifndef AUDIO_DEVICES_SELECTION
 	updateDriverCombos();
+#endif
 
     // Icons
 	/*
@@ -317,6 +316,31 @@ void PrefGeneral::setData(Preferences * pref) {
 
 	setMcActivated( pref->use_mc );
 	setMc( pref->mc_value );
+
+#ifdef AUDIO_DEVICES_SELECTION
+#if USE_PULSEAUDIO_DEVICES
+	#if USE_MPV_PULSE_DEVICES
+	if (PlayerID::player(pref->mplayer_bin) == PlayerID::MPLAYER)
+	#endif
+	{
+		pa_devices = DeviceInfo::paDevices();
+	}
+#endif
+#if MPV_AUDIO_DEVICES
+	if (PlayerID::player(pref->mplayer_bin) == PlayerID::MPV) {
+		#if USE_MPV_PULSE_DEVICES
+		pa_devices = DeviceInfo::mpvPulseDevices();
+		#endif
+		#if USE_MPV_ALSA_DEVICES
+		mpv_alsa_devices = DeviceInfo::mpvAlsaDevices();
+		#endif
+		#if USE_MPV_COREAUDIO_DEVICES
+		coreaudio_devices = DeviceInfo::mpvCoreaudioDevices();
+		#endif
+	}
+#endif
+	updateDriverCombos();
+#endif // AUDIO_DEVICES_SELECTION
 }
 
 void PrefGeneral::getData(Preferences * pref) {
@@ -324,6 +348,7 @@ void PrefGeneral::getData(Preferences * pref) {
 	filesettings_method_changed = false;
 
 	QString player_path = mplayerPath();
+#ifdef MPLAYER_MPV_SELECTION
 	#ifdef OS_UNIX_NOT_MAC
 	if (player_path == PLAYER_COMBO_MPLAYER_PATH || player_path == PLAYER_COMBO_MPV_PATH || !QFile::exists(player_path)) {
 		QString player_name = QFileInfo(player_path).fileName();
@@ -331,6 +356,7 @@ void PrefGeneral::getData(Preferences * pref) {
 		if (!found_player.isEmpty()) player_path = found_player;
 	}
 	#endif
+#endif
 	qDebug() << "PrefGeneral::getData: player_path:" << player_path;
 
 	if (pref->mplayer_bin != player_path) {
@@ -519,6 +545,7 @@ void PrefGeneral::updateDriverCombos() {
 		}
 		#endif
 		*/
+		#ifdef AUDIO_DEVICES_SELECTION
 		#if USE_ALSA_DEVICES
 		if ((ao == "alsa") && (!alsa_devices.isEmpty())) {
 			for (int n=0; n < alsa_devices.count(); n++) {
@@ -533,13 +560,20 @@ void PrefGeneral::updateDriverCombos() {
 			}
 		}
 		#endif
-		#if USE_PULSEAUDIO_DEVICES
+		#if USE_PULSEAUDIO_DEVICES || USE_MPV_PULSE_DEVICES
 		if ((ao == "pulse") && (!pa_devices.isEmpty())) {
 			for (int n=0; n < pa_devices.count(); n++) {
 				ao_combo->addItem( DeviceInfo::printableName("pulse", pa_devices[n]), DeviceInfo::internalName("pulse", pa_devices[n]) );
 			}
 		}
 		#endif
+		#if USE_MPV_COREAUDIO_DEVICES
+		if ((ao == "coreaudio") && (!coreaudio_devices.isEmpty())) {
+			for (int n=0; n < coreaudio_devices.count(); n++) {
+				ao_combo->addItem( DeviceInfo::printableName("coreaudio", coreaudio_devices[n]), DeviceInfo::internalName("coreaudio", coreaudio_devices[n]) );
+			}
+		}
+		#endif
 		#if USE_DSOUND_DEVICES
 		if ((ao == "dsound") && (!dsound_devices.isEmpty())) {
 			for (int n=0; n < dsound_devices.count(); n++) {
@@ -547,6 +581,7 @@ void PrefGeneral::updateDriverCombos() {
 			}
 		}
 		#endif
+		#endif // AUDIO_DEVICES_SELECTION
 	}
 	ao_combo->addItem( tr("User defined..."), "user_defined" );
 
